@@ -2,11 +2,12 @@
 ##
 ##  Call 'rcmdcheck' on a package
 ##
-##  Copyright (C) 2016 - 2017  Dirk Eddelbuettel
+##  Copyright (C) 2016 - 2018  Dirk Eddelbuettel
 ##
 ##  Released under GPL (>= 2)
 
-suppressMessages(library(docopt))       # we need docopt (>= 0.3) as on CRAN
+## load docopt package from CRAN
+library(docopt)
 
 ## configuration for docopt
 doc <- "Usage: rcc.r [-h] [-x] [-c] [-f] [-q] [--args ARGS] [--libpath LIBP] [--repos REPO] [PATH...]
@@ -33,7 +34,7 @@ See http://dirk.eddelbuettel.com/code/littler.html for more information.\n")
     q("no")
 }
 
-if (opt$args == "") {                   # special treatment for --args and -c
+if (is.null(opt$args)) {         # special treatment for --args and -c
     if (opt$`as-cran`) {
         opt$args <- "--as-cran"
     } else {
@@ -45,12 +46,12 @@ if (opt$args == "") {                   # special treatment for --args and -c
     }
 }
 if (opt$fast) {
-    opt$args <- c(opt$args, "--ignore-vignettes --no-manual")
+    opt$args <- c(opt$args, "--ignore-vignettes", "--no-manual")
 }
 
 if (length(opt$PATH) == 0) opt$PATH <- "." 		# default argument current directory
-if (opt$libpath == "") opt$libpath <- .libPaths()	# default library pathr
-if (opt$repos == "") opt$repos <- getOption("repos")	# default repos
+if (is.null(opt$libpath)) opt$libpath <- .libPaths()	# default library pathr
+if (is.null(opt$repos)) opt$repos <- getOption("repos")	# default repos
 
 if (requireNamespace("rcmdcheck", quietly=TRUE) == FALSE)
     stop("This command requires the 'rcmdcheck' package.", call.=FALSE)
